﻿using AutoMapper;
using Performance.DtoModels;
using Performance.Repository;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Performance.Services
{
    public class ComputeService : IAutoInjection
    {
        private PerforResAccountdoctorRepository _perforResAccountdoctorRepository;
        private PerforResAccountnurseRepository _perforResAccountnurseRepository;
        private PerforPerSheetRepository _perforPerSheetRepository;
        private PerforImDataRepository _perforImDataRepository;
        public ComputeService(PerforResAccountdoctorRepository perforResAccountdoctorRepository,
            PerforResAccountnurseRepository perforResAccountnurseRepository,
            PerforPerSheetRepository perforPerSheetRepository,
            PerforImDataRepository perforImDataRepository)
        {
            _perforResAccountdoctorRepository = perforResAccountdoctorRepository;
            _perforResAccountnurseRepository = perforResAccountnurseRepository;
            _perforPerSheetRepository = perforPerSheetRepository;
            _perforImDataRepository = perforImDataRepository;
        }

        /// <summary>
        /// 返回科室详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        public DeptDetailResponse GetDepartmentDetail(DeptDetailRequest request)
        {
            var sheetList = _perforPerSheetRepository.GetEntities(t => t.AllotID == request.AllotId);
            if (request.Type == 1)
            {
                var doctor = _perforResAccountdoctorRepository.GetEntity(t => t.AllotID == request.AllotId && t.ID == request.AccountID);

                DeptDetailResponse response = new DeptDetailResponse()
                {
                    Pandect = Mapper.Map<PerDataAccount>(doctor),
                    Economic = new List<DeptDetail>(),
                    Workload = new List<DeptDetail>()
                };

                var sheetWorkload = sheetList.FirstOrDefault(t => t.SheetType == (int)SheetType.ComputeDoctorWorkload);
                if (sheetWorkload == null)
                    return null;
                var dataWorkloadList = _perforImDataRepository.GetEntities(t => t.SheetID == sheetWorkload.ID && t.IsTotal != 1 && t.AccountingUnit == doctor.AccountingUnit);
                dataWorkloadList.ForEach(t => response.Workload.Add(new DeptDetail { ItemName = t.TypeName, ItemValue = t.CellValue ?? 0 }));

                var sheetEconomic = sheetList.FirstOrDefault(t => t.SheetType == (int)SheetType.ComputeEconomic);
                if (sheetEconomic == null)
                    return null;
                var dataEconomicList = _perforImDataRepository.GetEntities(t => t.SheetID == sheetEconomic.ID && t.UnitType == 1 && t.IsTotal != 1 && t.AccountingUnit == doctor.AccountingUnit);
                dataEconomicList.ForEach(t => response.Economic.Add(new DeptDetail { ItemName = t.TypeName, ItemValue = t.CellValue ?? 0 }));

                return response;
            }
            else if (request.Type == 2)
            {
                var nurse = _perforResAccountnurseRepository.GetEntity(t => t.AllotID == request.AllotId && t.ID == request.AccountID);
                DeptDetailResponse response = new DeptDetailResponse()
                {
                    Pandect = Mapper.Map<PerDataAccount>(nurse),
                    Economic = new List<DeptDetail>(),
                    Workload = new List<DeptDetail>()
                };

                var sheetWorkload = sheetList.FirstOrDefault(t => t.SheetType == (int)SheetType.ComputeNurseWorkload);
                if (sheetWorkload == null)
                    return null;
                var dataWorkloadList = _perforImDataRepository.GetEntities(t => t.SheetID == sheetWorkload.ID && t.IsTotal != 1 && t.AccountingUnit == nurse.AccountingUnit);
                dataWorkloadList.ForEach(t => response.Workload.Add(new DeptDetail { ItemName = t.TypeName, ItemValue = t.CellValue ?? 0 }));

                var sheetEconomic = sheetList.FirstOrDefault(t => t.SheetType == (int)SheetType.ComputeEconomic);
                if (sheetEconomic == null)
                    return null;
                var dataEconomicList = _perforImDataRepository.GetEntities(t => t.SheetID == sheetEconomic.ID && t.UnitType == 2 && t.IsTotal != 1 && t.AccountingUnit == nurse.AccountingUnit);
                dataEconomicList.ForEach(t => response.Economic.Add(new DeptDetail { ItemName = t.TypeName, ItemValue = t.CellValue ?? 0 }));
            }

            return null;
        }
    }
}
